@@ -8,8 +8,8 @@ class PatentPage(qrunner.Page):
     LOC_SEARCH_SUBMIT = {'id_': 'driver-home-step2', 'desc': '查专利首页搜索确认按钮'}
     
     def simple_search(self):
-        self.elem(self.LOC_SEARCH_INPUT).set_text('无人机')
-        self.elem(self.LOC_SEARCH_SUBMIT).click()
+        self.elem(**self.LOC_SEARCH_INPUT).set_text('无人机')
+        self.elem(**self.LOC_SEARCH_SUBMIT).click()
 
 
 @story('专利检索')
