@@ -109,18 +109,22 @@ class TestCase(HttpRequest):
             return WebElement(self.driver, **kwargs)
         elif isinstance(self.driver, IosDriver):
             return IosElement(self.driver, **kwargs)
+        else:
+            return None
 
     def assertText(self, expect_value, timeout=5):
         """断言页面包含文本"""
         for _ in range(timeout + 1):
             try:
                 page_source = self.driver.get_page_content()
+                logger.info(f'断言: {page_source}\n包含 {expect_value}')
                 assert expect_value in page_source, f'页面内容不包含 {expect_value}'
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             page_source = self.driver.get_page_content()
+            logger.info(f'断言: {page_source}\n包含 {expect_value}')
             assert expect_value in page_source, f'页面内容不包含 {expect_value}'
 
     def assertNotText(self, expect_value, timeout=5):
@@ -128,38 +132,51 @@ class TestCase(HttpRequest):
         for _ in range(timeout + 1):
             try:
                 page_source = self.driver.get_page_content()
+                logger.info(f'断言: {page_source}\n不包含 {expect_value}')
                 assert expect_value not in page_source, f'页面内容不包含 {expect_value}'
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             page_source = self.driver.get_page_content()
+            logger.info(f'断言: {page_source}\n不包含 {expect_value}')
             assert expect_value not in page_source, f'页面内容仍然包含 {expect_value}'
 
     def assertElement(self, timeout=5, **kwargs):
         """断言元素存在"""
         for _ in range(timeout + 1):
             try:
-                element = self.elem(**kwargs)
-                assert element.exists(), f'元素 {kwargs} 不存在'
+                flag = self.elem(**kwargs).exists()
+                logger.info(f'断言: 元素 {kwargs} 存在结果为 {flag}')
+                assert flag, f'元素 {kwargs} 不存在'
                 break
             except AssertionError:
                 time.sleep(1)
         else:
-            assert self.elem(**kwargs).exists(), f'元素 {kwargs} 不存在'
+            flag = self.elem(**kwargs).exists()
+            logger.info(f'断言: 元素 {kwargs} 存在结果为 {flag}')
+            assert flag, f'元素 {kwargs} 不存在'
 
     def assertNotElement(self, timeout=5, **kwargs):
         """断言元素不存在"""
         for _ in range(timeout + 1):
             try:
-                assert not self.elem(**kwargs).exists(), f'元素 {kwargs} 仍然存在'
+                flag = self.elem(**kwargs).exists()
+                logger.info(f'断言: 元素 {kwargs} 存在结果为 {flag}')
+                assert not flag, f'元素 {kwargs} 仍然存在'
                 break
             except AssertionError:
                 time.sleep(1)
         else:
-            assert not self.elem(**kwargs).exists(), f'元素 {kwargs} 仍然存在'
+            flag = self.elem(**kwargs).exists()
+            logger.info(f'断言: 元素 {kwargs} 存在结果为 {flag}')
+            assert not flag, f'元素 {kwargs} 仍然存在'
 
     # WEB专用方法
+    def open(self, url=None):
+        """打开页面"""
+        self.driver.open_url(url)
+
     def switch_frame(self, frame_id: str):
         """切换到iframe中"""
         self.driver.switch_to_frame(frame_id)
@@ -182,12 +199,14 @@ class TestCase(HttpRequest):
         for _ in range(timeout + 1):
             try:
                 title = self.driver.get_title()
+                logger.info(f'断言: 页面标题 {title} 等于 {expect_value}')
                 assert expect_value == title, f'页面标题 {title} 不等于 {expect_value}'
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             title = self.driver.get_title()
+            logger.info(f'断言: 页面标题 {title} 等于 {expect_value}')
             assert expect_value == title, f'页面标题 {title} 不等于 {expect_value}'
 
     def assertInTitle(self, expect_value=None, timeout=5):
@@ -195,12 +214,14 @@ class TestCase(HttpRequest):
         for _ in range(timeout + 1):
             try:
                 title = self.driver.get_title()
+                logger.info(f'断言: 页面标题 {title} 包含 {expect_value}')
                 assert expect_value in title, f'页面标题 {title} 不包含 {expect_value}'
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             title = self.driver.get_title()
+            logger.info(f'断言: 页面标题 {title} 包含 {expect_value}')
             assert expect_value in title, f'页面标题 {title} 不包含 {expect_value}'
 
     def assertUrl(self, expect_value=None, timeout=5):
@@ -208,12 +229,14 @@ class TestCase(HttpRequest):
         for _ in range(timeout + 1):
             try:
                 url = self.driver.get_url()
+                logger.info(f'断言: 页面url {url} 等于 {expect_value}')
                 assert expect_value == url, f'页面url {url} 不等于 {expect_value}'
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             url = self.driver.get_url()
+            logger.info(f'断言: 页面url {url} 等于 {expect_value}')
             assert expect_value == url, f'页面url {url} 不等于 {expect_value}'
 
     def assertInUrl(self, expect_value=None, timeout=5):
@@ -221,17 +244,20 @@ class TestCase(HttpRequest):
         for _ in range(timeout + 1):
             try:
                 url = self.driver.get_url()
+                logger.info(f'断言: 页面url {url} 包含 {expect_value}')
                 assert expect_value in url, f'页面url {url} 不包含 {expect_value}'
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             url = self.driver.get_url()
+            logger.info(f'断言: 页面url {url} 包含 {expect_value}')
             assert expect_value in url, f'页面url {url} 不包含 {expect_value}'
 
     def assertAlertText(self, expect_value):
         """断言弹窗文本"""
         alert_text = self.driver.get_alert_text()
+        logger.info(f'断言: 弹窗文本 {alert_text} 等于 {expect_value}')
         assert expect_value == alert_text, f'弹窗文本 {alert_text} 等于 {expect_value}'
 
     # APP专用方法
@@ -261,10 +287,10 @@ class TestCase(HttpRequest):
         """
         断言状态码
         """
-        with step(f'断言响应状态码 == {status_code}'):
-            actual_code = ResponseResult.status_code
-            assert actual_code == status_code, \
-                f'status_code {ResponseResult} != {status_code}'
+        actual_code = ResponseResult.status_code
+        logger.info(f'断言: {actual_code} 等于 {status_code}')
+        assert actual_code == status_code, \
+            f'status_code {ResponseResult} != {status_code}'
 
     @staticmethod
     def assertPath(path, value):
@@ -272,9 +298,9 @@ class TestCase(HttpRequest):
         功能同assertEq，用于兼容历史代码
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} == {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert search_value == value, f'{search_value} != {value}'
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 等于 {value}')
+        assert search_value == value, f'{search_value} != {value}'
 
     @staticmethod
     def assertNotEq(path, value):
@@ -282,9 +308,9 @@ class TestCase(HttpRequest):
         值不等于
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} != {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert search_value != value, f"{search_value} 等于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 不等于 {value}')
+        assert search_value != value, f"{search_value} 等于 {value}"
 
     @staticmethod
     def assertLenEq(path, value):
@@ -292,9 +318,9 @@ class TestCase(HttpRequest):
         断言列表长度等于多少
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 的长度 == {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {len(search_value)} 等于 {value}')
+        assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
 
     @staticmethod
     def assertLenGt(path, value):
@@ -302,9 +328,9 @@ class TestCase(HttpRequest):
         断言列表长度大于多少
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 的长度 > {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {len(search_value)} 大于 {value}')
+        assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
     def assertLenGtOrEq(path, value):
@@ -312,9 +338,9 @@ class TestCase(HttpRequest):
         断言列表长度大于等于多少
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 的长度 >= {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert len(search_value) >= value, f"{search_value} 的长度不大于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {len(search_value)} 大于等于 {value}')
+        assert len(search_value) >= value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
     def assertLenLt(path, value):
@@ -322,9 +348,9 @@ class TestCase(HttpRequest):
         断言列表长度小于多少
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 的长度 < {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert len(search_value) < value, f"{search_value} 的长度不大于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {len(search_value)} 小于 {value}')
+        assert len(search_value) < value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
     def assertLenLtOrEq(path, value):
@@ -332,9 +358,9 @@ class TestCase(HttpRequest):
         断言列表长度小于等于多少
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 的长度 <= {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert len(search_value) <= value, f"{search_value} 的长度不大于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {len(search_value)} 小于等于 {value}')
+        assert len(search_value) <= value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
     def assertGt(path, value):
@@ -342,14 +368,14 @@ class TestCase(HttpRequest):
         值大于多少
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} > {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            if isinstance(search_value, str):
-                if '.' in search_value:
-                    search_num = float(search_value)
-                else:
-                    search_num = int(search_value)
-            assert search_num > value, f"{search_value} 不大于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if '.' in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f'断言: {search_value} 大于 {value}')
+        assert search_value > value, f"{search_value} 不大于 {value}"
 
     @staticmethod
     def assertGtOrEq(path, value):
@@ -357,14 +383,14 @@ class TestCase(HttpRequest):
         值大于等于
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} >= {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            if isinstance(search_value, str):
-                if '.' in search_value:
-                    search_value = float(search_value)
-                else:
-                    search_value = int(search_value)
-            assert search_value >= value, f"{search_value} 小于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if '.' in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f'断言: {search_value} 大于等于 {value}')
+        assert search_value >= value, f"{search_value} 小于 {value}"
 
     @staticmethod
     def assertLt(path, value):
@@ -372,14 +398,14 @@ class TestCase(HttpRequest):
         值小于多少
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} < {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            if isinstance(search_value, str):
-                if '.' in search_value:
-                    search_value = float(search_value)
-                else:
-                    search_value = int(search_value)
-            assert search_value < value, f"{search_value} 不大于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if '.' in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f'断言: {search_value} 小于 {value}')
+        assert search_value < value, f"{search_value} 不大于 {value}"
 
     @staticmethod
     def assertLtOrEq(path, value):
@@ -387,28 +413,28 @@ class TestCase(HttpRequest):
         值小于等于多少
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} <= {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            if isinstance(search_value, str):
-                if '.' in search_value:
-                    search_value = float(search_value)
-                else:
-                    search_value = int(search_value)
-            assert search_value <= value, f"{search_value} 不大于 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if '.' in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f'断言: {search_value} 小于等于 {value}')
+        assert search_value <= value, f"{search_value} 不大于 {value}"
 
     @staticmethod
     def assertRange(path, start, end):
         """值在(start, end)范围内
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 在({start}, {end})范围内'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            if isinstance(search_value, str):
-                if '.' in search_value:
-                    search_value = float(search_value)
-                else:
-                    search_value = int(search_value)
-            assert (search_value >= start) & (search_value <= end), f'{search_value} 不在[{start}, {end}]范围内'
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if '.' in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f'断言: {search_value} 在 [{start}, {end}] 范围内')
+        assert (search_value >= start) & (search_value <= end), f'{search_value} 不在[{start}, {end}]范围内'
 
     @staticmethod
     def assertIn(path, value):
@@ -416,9 +442,9 @@ class TestCase(HttpRequest):
         断言匹配结果被value_list包含
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 被 {value} 包含'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert search_value in value, f"{value} 不包含 {search_value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 被 {value} 包含')
+        assert search_value in value, f"{value} 不包含 {search_value}"
 
     @staticmethod
     def assertNotIn(path, value):
@@ -426,16 +452,16 @@ class TestCase(HttpRequest):
         断言匹配结果不被value_list包含
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 不被 {value} 包含'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert search_value not in value, f"{value} 包含 {search_value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 不被 {value} 包含')
+        assert search_value not in value, f"{value} 包含 {search_value}"
 
     @staticmethod
     def assertNotExists(path):
         """断言字段不存在"""
-        with step(f'断言响应中 {path} 值为None或字段不存在'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert search_value is None, f'仍然包含 {path} 为 {search_value}'
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {path} 不存在或值为None')
+        assert search_value is None, f'仍然包含 {path} 为 {search_value}'
 
     @staticmethod
     def assertContains(path, value):
@@ -443,9 +469,9 @@ class TestCase(HttpRequest):
         断言匹配结果包含value
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 包含 {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert value in search_value, f"{search_value} 不包含 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 包含 {value}')
+        assert value in search_value, f"{search_value} 不包含 {value}"
 
     @staticmethod
     def assertNotContains(path, value):
@@ -453,9 +479,9 @@ class TestCase(HttpRequest):
         断言匹配结果不包含value
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 不包含 {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert value not in search_value, f"{search_value} 包含 {value}"
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 不包含 {value}')
+        assert value not in search_value, f"{search_value} 包含 {value}"
 
     @staticmethod
     def assertTypeMatch(path, value_type):
@@ -463,21 +489,21 @@ class TestCase(HttpRequest):
         类型匹配
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 的数据类型等于 {value_type}'):
-            if not isinstance(value_type, type):
-                if value_type == 'int':
-                    value_type = int
-                elif value_type == 'str':
-                    value_type = str
-                elif value_type == 'list':
-                    value_type = list
-                elif value_type == 'dict':
-                    value_type = dict
-                else:
-                    value_type = str
+        if not isinstance(value_type, type):
+            if value_type == 'int':
+                value_type = int
+            elif value_type == 'str':
+                value_type = str
+            elif value_type == 'list':
+                value_type = list
+            elif value_type == 'dict':
+                value_type = dict
+            else:
+                value_type = str
 
-            search_value = jmespath.search(path, ResponseResult.response)
-            assert isinstance(search_value, value_type), f'{search_value} 不是 {value_type} 类型'
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 是 {value_type} 类型')
+        assert isinstance(search_value, value_type), f'{search_value} 不是 {value_type} 类型'
 
     @staticmethod
     def assertStartsWith(path, value):
@@ -485,9 +511,9 @@ class TestCase(HttpRequest):
         以什么开头
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 以 {value} 开头'):
-            search_value: str = jmespath.search(path, ResponseResult.response)
-            assert search_value.startswith(value), f'{search_value} 不以 {value} 开头'
+        search_value: str = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 以 {value} 开头')
+        assert search_value.startswith(value), f'{search_value} 不以 {value} 开头'
 
     @staticmethod
     def assertEndsWith(path, value):
@@ -495,9 +521,9 @@ class TestCase(HttpRequest):
         以什么结尾
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 以 {value} 结尾'):
-            search_value: str = jmespath.search(path, ResponseResult.response)
-            assert search_value.endswith(value), f'{search_value} 不以 {value} 结尾'
+        search_value: str = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 以 {value} 结尾')
+        assert search_value.endswith(value), f'{search_value} 不以 {value} 结尾'
 
     @staticmethod
     def assertRegexMatch(path, value):
@@ -505,7 +531,7 @@ class TestCase(HttpRequest):
         正则匹配
         doc: https://jmespath.org/
         """
-        with step(f'断言响应中 {path} 正则匹配表达式 {value}'):
-            search_value = jmespath.search(path, ResponseResult.response)
-            match_obj = re.match(r'' + value, search_value, flags=re.I)
-            assert match_obj is not None, f'结果 {search_value} 匹配失败'
+        search_value = jmespath.search(path, ResponseResult.response)
+        match_obj = re.match(r'' + value, search_value, flags=re.I)
+        logger.info(f'断言: {search_value} 匹配正则表达式 {value} 成功')
+        assert match_obj is not None, f'结果 {search_value} 匹配失败'
