@@ -8,7 +8,7 @@ import wda
 
 from qrunner.core.ios.common import get_device_list, get_tcp_port
 from qrunner.utils.log import logger
-from qrunner.utils.config import conf
+from qrunner.utils.config import config
 from qrunner.utils.exceptions import DeviceNotFoundException, ScreenFailException
 
 
@@ -34,19 +34,18 @@ class IosDriver(object):
     _instance = {}
 
     def __new__(cls, serial_no=None, bundle_id=None):
-        if not serial_no:
-            serial_no = conf.get_item('ios', 'serial_no')
         if serial_no not in cls._instance:
             cls._instance[serial_no] = super().__new__(cls)
         return cls._instance[serial_no]
 
     def __init__(self, serial_no=None):
-        self.serial_no = serial_no if serial_no else conf.get_item('ios', 'serial_no')
+        self.serial_no = serial_no if serial_no else config.get_device()
         if serial_no in get_device_list():
             self.serial_no = serial_no
         else:
             raise DeviceNotFoundException(msg=f'设备 {serial_no} 未连接')
-        self.bundle_id = conf.get_item('ios', 'pkg_name')
+        self.bundle_id = config.get_pkg()
+        logger.debug(self.bundle_id)
         logger.info(f'启动 ios driver for {self.serial_no}')
         # 启动wda
         port = get_tcp_port(self.serial_no)
@@ -196,8 +195,7 @@ class IosDriver(object):
     #     allure.attach.file(file_path, attachment_type=allure.attachment_type.PNG, name=f'{file_name}.png')
     #     return file_path
 
-    @property
-    def page_content(self):
+    def get_page_content(self):
         """获取页面xml内容"""
         page_source = self.d.source(accessible=False)
         logger.info(f'获取页面内容: \n{page_source}')
