@@ -34,14 +34,14 @@ class Page(object):
             logger.error(f'请设置页面url: {str(e)}')
             sys.exit()
 
-    def elem(self, loc_dict: dict):
+    def elem(self, **kwargs):
         """页面元素封装"""
         if isinstance(self.driver, AndroidDriver):
-            return AndroidElement(**loc_dict)
+            return AndroidElement(**kwargs)
         elif isinstance(self.driver, WebDriver):
-            return WebElement(**loc_dict)
+            return WebElement(**kwargs)
         elif isinstance(self.driver, IosDriver):
-            return IosElement(**loc_dict)
+            return IosElement(**kwargs)
 
 
 
