@@ -20,6 +20,7 @@ class TestMain(object):
                  base_url: str = None,
                  headers: dict = None,
                  timeout: int = 10,
+                 env: str = None,
                  ):
         """
 
@@ -49,6 +50,7 @@ class TestMain(object):
             visit_headers = headers.pop('visit_headers', {})
             config.set('common', 'visit_headers', visit_headers)
         config.set('common', 'timeout', timeout)
+        config.set('common', 'env', env)
 
         # 执行用例
         logger.info('执行用例')
