@@ -9,16 +9,18 @@ root_path = os.path.dirname(local_path)
 class Config:
     def __init__(self):
         self.file_path = os.path.join(root_path, 'running', 'conf.yml')
-        with open(self.file_path, "r", encoding="utf-8") as f:
-            self.yaml_data = yaml.load(f.read(), Loader=yaml.FullLoader)
 
     def get(self, module, key):
-        return self.yaml_data[module][key]
+        with open(self.file_path, "r", encoding="utf-8") as f:
+            yaml_data = yaml.load(f.read(), Loader=yaml.FullLoader)
+        return yaml_data[module][key]
 
     def set(self, module, key, value):
-        self.yaml_data[module][key] = value
+        with open(self.file_path, "r", encoding="utf-8") as f:
+            yaml_data = yaml.load(f.read(), Loader=yaml.FullLoader)
+        yaml_data[module][key] = value
         with open(self.file_path, 'w', encoding="utf-8") as f:
-            yaml.dump(self.yaml_data, f)
+            yaml.dump(yaml_data, f)
 
     def get_platform(self):
         return self.get('common', 'platform')
@@ -44,6 +46,9 @@ class Config:
     def get_timeout(self):
         return self.get('common', 'timeout')
 
+    def get_env(self):
+        return self.get('common', 'env')
+
 
 config = Config()
 
