@@ -9,6 +9,10 @@ import inspect as sys_inspect
 
 
 # 报告模块
+from qrunner import logger
+from qrunner.utils.config import config
+
+
 def feature(text):
     return allure.feature(text)
 
@@ -61,6 +65,8 @@ def data(*args, **kwargs):
 
 # 从json文件获取数据进行参数化
 def file_data(key=None, file='data.json'):
+    # logger.debug(config.get_env())
+
     """
     @param file: 文件名，默认为data.json，从data.json文件中取值默认可以不填
     @param key: json文件中一级字典的key，必填
@@ -69,6 +75,7 @@ def file_data(key=None, file='data.json'):
     stack_t = sys_inspect.stack()
     ins = sys_inspect.getframeinfo(stack_t[1][0])
     file_dir = os.path.dirname(os.path.abspath(ins.filename))
+    logger.debug(file_dir)
     parent_dir = os.path.dirname(file_dir)
     parent_dir_dir = os.path.dirname(parent_dir)
     parent_dir_dir_dir = os.path.dirname(parent_dir_dir)
@@ -78,7 +85,11 @@ def file_data(key=None, file='data.json'):
     file_path = None
     full_list = []
     for _path in path_list:
-        full_path = os.path.join(_path, 'test_data', file)
+        environ = config.get_env()
+        if environ:
+            full_path = os.path.join(_path, 'test_data', environ, file)
+        else:
+            full_path = os.path.join(_path, 'test_data', file)
         full_list.append(full_path)
         # print(full_path)
         if os.path.isfile(full_path) is True:
@@ -87,6 +98,8 @@ def file_data(key=None, file='data.json'):
     if file_path is None:
         raise Exception(f"can not found {file} in {full_list}")
 
+    logger.debug(file_path)
+
     # 根据文件路径以及key获取文件中的数据，暂时只支持json文件
     with open(file_path, 'r', encoding='utf-8') as f:
         json_data = json.load(f)
